#ifndef squeezster_ICONS_H
#define squeezster_ICONS_H

#define POWERPIXMAPFILE ":/images/power_symbonly.png"
#define POWERREDPIXMAPFILE ":/images/power_red_symbonly.png"
#define POWERGREENPIXMAPFILE ":/images/power_green_symbonly.png"
#define PLAYPIXMAPFILE ":/images/play_symbonly.png"
#define STOPPIXMAPFILE ":/images/stop_symbonly.png"
#define PAUSEPIXMAPFILE ":/images/pause_symbonly.png"
#define FWDPIXMAPFILE ":/images/fwd_symbonly.png"
#define REWPIXMAPFILE ":/images/rew_symbonly.png"
#define MINUSPIXMAPFILE ":/images/minus_symbonly.png"
#define BULLETPIXMAPFILE ":/images/bullet_symbonly.png"
#define PLUSPIXMAPFILE ":/images/plus_symbonly.png"
#define SMALLPLUSPIXMAPFILE ":/images/smallplus_symbonly.png"
#define SMALLMINUSPIXMAPFILE ":/images/smallminus_symbonly.png"
#define SMALLBULLETPIXMAPFILE ":/images/smallbullet_symbonly.png"
#define WHITENOTEPIXMAPFILE ":/images/whitenot.png"
#define MUSICNOTESPIXMAPFILE ":/images/musicnotes.png"
#define WHITEHEARTPIXMAPFILE ":/images/whiteheart.png"
#define RADIOPIXMAPFILE ":/images/radio.png"
#define LARGEEMPTYALBUMARTPIXMAPFILE ":/images/cd_grey.png"
#define SMALLEMPTYALBUMARTPIXMAPFILE ":/images/cd_grey_small.png"
#define FOLDERPIXMAPFILE ":/images/folder.png"
#define LIBRARYPIXMAPFILE ":/images/library.png"
#define LOCALALBUMARTSUFFIX "/cover_415x415.jpg"
#define LARGERALBUMARTSUFFIX "/cover_112x112.jpg"
#define SMALLALBUMARTSUFFIX "/cover_50x50.jpg"
//#define LOCALALBUMARTSUFFIX "/cover.jpg"

#define ALBUMART_WIDTH 415
//#define SMALLICON_WIDTH 60
//#define LARGEICON_WIDTH 112

Q_DECLARE_METATYPE(QVariantHash*)

#endif // squeezster_ICONS_H
